@@ -61,7 +61,7 @@ class DocumenterBridge:
         self.state = state
 
     def warn(self, msg: str) -> None:
-        warnings.warn('DocumenterBridge.warn is deprecated.  Plase use sphinx.util.logging '
+        warnings.warn('DocumenterBridge.warn is deprecated.  Please use sphinx.util.logging '
                       'module instead.',
                       RemovedInSphinx60Warning, stacklevel=2)
         logger.warning(msg, location=(self.env.docname, self.lineno))
@@ -107,7 +107,7 @@ def process_documenter_options(documenter: Type[Documenter], config: Config, opt
 
 def parse_generated_content(state: RSTState, content: StringList, documenter: Documenter
                             ) -> List[Node]:
-    """Parse a generated content by Documenter."""
+    """Parse an item of content generated by Documenter."""
     with switch_source_input(state, content):
         if documenter.titles_allowed:
             node: Element = nodes.section()
@@ -125,8 +125,8 @@ def parse_generated_content(state: RSTState, content: StringList, documenter: Do
 class AutodocDirective(SphinxDirective):
     """A directive class for all autodoc directives. It works as a dispatcher of Documenters.
 
-    It invokes a Documenter on running. After the processing, it parses and returns
-    the generated content by Documenter.
+    It invokes a Documenter upon running. After the processing, it parses and returns
+    the content generated by Documenter.
     """
     option_spec = DummyOptionSpec()
     has_content = True
